#!/bin/bash

# Check if a directory is provided as an argument
if [ $# -eq 0 ]; then
    echo "Please provide a directory path as an argument."
    exit 1
fi

directory="$1"

# Check if the provided path is a valid directory
if [ ! -d "$directory" ]; then
    echo "Error: '$directory' is not a valid directory."
    exit 1
fi

# Calculate total size and count of files/directories
total_size=0
count=0

while IFS= read -r -d '' item; do
    if [ "$item" != "$directory" ]; then
        size=$(stat -f '%z' "$item")
        total_size=$((total_size + size))
        count=$((count + 1))
        echo "$item: $size bytes"
    fi
done < <(find "$directory" -print0)

# Calculate average size
if [ $count -gt 0 ]; then
    average_size=$((total_size / count))
    echo "Total size: $total_size bytes"
    echo "Number of items: $count"
    echo "Average size: $average_size bytes"
else
    echo "The directory is empty."
fi
